@@ -321,15 +321,18 @@ zval *php_lua_get_zval_from_lua(lua_State *L, int index, zval *lua_obj, zval *rv
 			break;
 		case LUA_TTABLE:
 			array_init(rv);
-			lua_pushnil(L);  /* first key */
-			while (lua_next(L, index-1) != 0) {
+			lua_pushvalue(L, index);  // table
+			lua_pushnil(L);  // first key
+			while (lua_next(L, -2) != 0) {
 				zval key, val;
 
-				/* uses 'key' (at index -2) and 'value' (at index -1) */
-				if (!php_lua_get_zval_from_lua(L, -2, lua_obj, &key)) {
+				lua_pushvalue(L, -2);
+
+				/* uses 'key' (at index -1) and 'value' (at index -2) */
+				if (!php_lua_get_zval_from_lua(L, -1, lua_obj, &key)) {
 					break;
 				}
-				if (!php_lua_get_zval_from_lua(L, -1, lua_obj, &val)) {
+				if (!php_lua_get_zval_from_lua(L, -2, lua_obj, &val)) {
 					zval_ptr_dtor(&key);
 					/* there is a warning already in php_lua_get_zval_from_lua */
 					break;
@@ -349,17 +352,13 @@ zval *php_lua_get_zval_from_lua(lua_State *L, int index, zval *lua_obj, zval *rv
 					default:
 						break;
 				}
-				lua_pop(L, 1);
+				lua_pop(L, 2);
 			}
+			lua_pop(L, 1);
 			break;
 		case LUA_TFUNCTION:
 			{
 				long ref_id = 0;
-				if (!lua_obj) {
-					php_error_docref(NULL, E_WARNING, "corrupted Lua object");
-					break;
-				}
-
 				lua_pushvalue(L, index);
 				ref_id = luaL_ref(L, LUA_REGISTRYINDEX);
 
@@ -425,7 +424,7 @@ try_again:
 					add_next_index_zval(callbacks, val);
 				} else {
 					zval *v;
-					ulong longkey;
+					zend_ulong longkey;
 					zend_string *key;
 					zval zkey;
 
@@ -458,13 +457,31 @@ try_again:
 					lua_newtable(L);
 
 					ZEND_HASH_FOREACH_KEY_VAL_IND(ht, longkey, key, v) {
+						zend_bool key_pushed = 0;
+
 						if (key) {
-							ZVAL_STR(&zkey, key);
+							if (Z_TYPE_P(val) == IS_OBJECT && ZSTR_VAL(key)[0] == 0) {
+								/* This is object property and it's name should be demangled*/
+								const char *prop_name, *class_name;
+								size_t prop_len;
+
+								zend_unmangle_property_name_ex(key, &class_name, &prop_name, &prop_len);
+
+								lua_pushlstring(L, prop_name, prop_len);
+								key_pushed = 1;
+							} else {
+								ZVAL_STR(&zkey, key);
+							}
 						} else {
 							ZVAL_LONG(&zkey, longkey);
 						}
-						php_lua_send_zval_to_lua(L, &zkey);
+
+						if (!key_pushed) {
+							php_lua_send_zval_to_lua(L, &zkey);
+						}
+
 						php_lua_send_zval_to_lua(L, v);
+
 						lua_settable(L, -3);
 					} ZEND_HASH_FOREACH_END();
 
