@@ -11,29 +11,15 @@
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author    : Johannes Schlueter  <johannes@php.net>                   |
-  |             Xinchen  Hui        <laruence@php.net>                   |
+  | 			Xinchen  Hui        <laruence@php.net>                   |
   |             Marcelo  Araujo     <msaraujo@php.net>                   |
-  |             Helmut  Januschka   <helmut@januschka.com>               |
   +----------------------------------------------------------------------+
+   $Id: lua_closure.h 319733 2011-11-24 07:13:56Z laruence $
 */
 
-#ifndef LUA_CLOSURE_H
-#define LUA_CLOSURE_H
-typedef struct _lua_closure_object {
-	long closure;
-	zval lua;
-
-	zend_object std;
-} lua_closure_object;
-
-static inline lua_closure_object* php_lua_closure_object_from_zend_object(zend_object *zobj) {
-	return ((lua_closure_object*)(zobj + 1)) - 1;
-}
-
-void php_lua_closure_register();
+void php_lua_closure_register(TSRMLS_D);
 zend_class_entry *php_lua_get_closure_ce();
-zval * php_lua_closure_instance(zval *instance, long ref_id, zval *lua_obj);
-#endif
+zval * php_lua_closure_instance(zval *instance, long ref_id, zval *lua_obj TSRMLS_DC);
 
 /*
  * Local variables:
